StickDragDetails class

Constructors

StickDragDetails(double x, double y, Alignment alignment, Offset currentOffset)

Properties

alignment Alignment
final
currentOffset Offset
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
x double
final
y double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited